Name:           acpica-tools
Version:        20130117
Release:        5%{?dist}
Summary:        ACPICA tools for the development and debug of ACPI tables

Group:          Development/Languages
License:        Intel ACPI or GPLv2
URL:            https://www.acpica.org/

# ACPI has only been implemented in useful ways on x86, x86_64, and
# ia64 architectures.  Current plans are for expanding ACPI support
# to ARM server architectures.  ARMv7 is possible, but not guaranteed,
# and AArch64, aka ARMv8, is almost certain.  Therefore, this package
# can safely exclude the following architectures as these tools will
# have no value on those systems.
ExcludeArch:    sparc s390 s390 ppc ppc64

Source0:        https://www.acpica.org/download/acpica-unix2-%{version}.tar.gz
Source1:        https://www.acpica.org/download/acpitests-unix-%{version}.tar.gz
Source2:        README.Fedora
Source3:        iasl.1
Source4:        acpibin.1
Source5:        acpiexec.1
Source6:        acpihelp.1
Source7:        acpinames.1
Source8:        acpisrc.1
Source9:        acpixtract.1
Source10:       badcode.asl.result
Source11:       grammar.asl.result
Source12:       run-misc-tests.sh
Source13:       License

Patch0:         acpica-tools-config.patch
Patch1:         iasl-signed-char.patch
Patch2:         debian-big_endian.patch
Patch3:         debian-unaligned.patch

BuildRequires:  bison patchutils flex

# The previous iasl package contained only a very small subset of these tools
# and it produced only the iasl package listed below; further, the pmtools
# package -- which provides acpidump -- also provides a /usr/sbin/acpixtract
# that we don't really want to collide with
Provides:       acpixtract
Provides:       iasl = %{version}-%{release}
Obsoletes:      iasl < 20120913-7


%description
The ACPI Component Architecture (ACPICA) project provides an OS-independent
reference implementation of the Advanced Configuration and Power Interface
Specification (ACPI).  ACPICA code contains those portions of ACPI meant to
be directly integrated into the host OS as a kernel-resident subsystem, and
a small set of tools to assist in developing and debugging ACPI tables.

This package contains only the user-space tools needed for ACPI table
development, not the kernel implementation of ACPI.  The following commands
are installed:
   -- iasl: compiles ASL (ACPI Source Language) into AML (ACPI Machine
      Language), suitable for inclusion as a DSDT in system firmware.
      It also can disassemble AML, for debugging purposes.
   -- acpibin: performs basic operations on binary AML files (e.g.,
      comparison, data extraction)
   -- acpiexec: simulate AML execution in order to debug method definitions
   -- acpihelp: display help messages describing ASL keywords and op-codes
   -- acpinames: display complete ACPI name space from input AML
   -- acpisrc: manipulate the ACPICA source tree and format source files
      for specific environments
   -- acpixtract: extract binary ACPI tables from acpidump output (see
      also the pmtools package)


%prep
%setup -q -n acpica-unix2-%{version}
%setup -T -D -a 1 -n acpica-unix2-%{version}
gzip -dc %{_sourcedir}/acpitests-unix-%{version}.tar.gz | tar -x --strip-components=1 -f -

%patch0 -p1 -b .acpica-tools-config
%patch1 -p1 -b .iasl-signed-char
%patch2 -p1 -b .debian-big_endian
%patch3 -p1 -b .debian-unaligned

cp -p %{SOURCE2} README.Fedora
cp -p %{SOURCE3} iasl.1
cp -p %{SOURCE4} acpibin.1
cp -p %{SOURCE5} acpiexec.1
cp -p %{SOURCE6} acpihelp.1
cp -p %{SOURCE7} acpinames.1
cp -p %{SOURCE8} acpisrc.1
cp -p %{SOURCE9} acpixtract.1
cp -p %{SOURCE10} badcode.asl.result
cp -p %{SOURCE11} grammar.asl.result
cp -p %{SOURCE12} tests/run-misc-tests.sh
cp -p %{SOURCE13} License

# spurious executable permissions on text files in upstream
chmod a-x changes.txt
chmod a-x source/compiler/new_table.txt


%build
# NB: this package does not use the %{optflags} macro
# Rationale: upstream claims that using -O will lead to miscompilation
#            and the resulting tools will be incorrect.  Since ACPI is
#            a reasonably critical part of the environment, we are erring
#            on the side of caution.  Furthermore, it is not important that
#            these tools operate more quickly than they do.  Their present
#            performance level is sufficient.
make


%install
rm -rf %{buildroot}

# Install the binaries
install -p -D generate/unix/bin*/iasl %{buildroot}%{_bindir}/iasl
install -p -D generate/unix/bin*/acpibin %{buildroot}%{_bindir}/acpibin
install -p -D generate/unix/bin*/acpiexec %{buildroot}%{_bindir}/acpiexec
install -p -D generate/unix/bin*/acpihelp %{buildroot}%{_bindir}/acpihelp
install -p -D generate/unix/bin*/acpinames %{buildroot}%{_bindir}/acpinames
install -p -D generate/unix/bin*/acpisrc %{buildroot}%{_bindir}/acpisrc
install -p -D generate/unix/bin*/acpixtract \
              %{buildroot}%{_bindir}/acpixtract-acpica

# Install the man pages
install -m 0644 -p -D iasl.1 %{buildroot}%{_mandir}/man1/iasl.1
install -m 0644 -p -D acpibin.1 %{buildroot}%{_mandir}/man1/acpibin.1
install -m 0644 -p -D acpiexec.1 %{buildroot}%{_mandir}/man1/acpiexec.1
install -m 0644 -p -D acpihelp.1 %{buildroot}%{_mandir}/man1/acpihelp.1
install -m 0644 -p -D acpinames.1 %{buildroot}%{_mandir}/man1/acpinames.1
install -m 0644 -p -D acpisrc.1 %{buildroot}%{_mandir}/man1/acpisrc.1
install -m 0644 -p -D acpixtract.1 \
                      %{buildroot}%{_mandir}/man1/acpixtract-acpica.1

%check
cd tests

# ASL tests
./aslts.sh                         # relies on non-zero exit
[ $? -eq 0 ] || exit 1

# API tests
# TODO: get the API tests working properly in Linux; at present, they
# do not build from source
#cd tests/aapits
#make
#cd asl
#make
#cd ../bin
#./aapitsrun
#cd ../..

# misc tests
./run-misc-tests.sh %{buildroot}%{_bindir}

# Template tests
cd templates
make
if [ -f diff.log ]
then
    if [ -s diff.log ]
    then
        exit 1                  # implies errors occurred
    fi
fi
cd ..


%post
alternatives --install %{_bindir}/acpixtract acpixtract \
                       %{_bindir}/acpixtract-acpica 100 \
               --slave %{_mandir}/man1/acpixtract.1.gz acpixtract.1.gz \
                       %{_mandir}/man1/acpixtract-acpica.1


%postun
if [ ! -e %{_bindir}/acpixtract-acpica ]
then
    alternatives --remove acpixtract %{_bindir}/acpixtract-acpica
fi


%clean
rm -rf %{buildroot}


%files
%defattr(-,root,root,-)
%doc changes.txt source/compiler/new_table.txt License
%doc README.Fedora

%{_bindir}/iasl
%{_bindir}/acpibin
%{_bindir}/acpiexec
%{_bindir}/acpihelp
%{_bindir}/acpinames
%{_bindir}/acpisrc
%{_bindir}/acpixtract-acpica

%{_mandir}/man1/iasl.1*
%{_mandir}/man1/acpibin.1*
%{_mandir}/man1/acpiexec.1*
%{_mandir}/man1/acpihelp.1*
%{_mandir}/man1/acpinames.1*
%{_mandir}/man1/acpisrc.1*
%{_mandir}/man1/acpixtract-acpica.1*


%changelog
* Thu Jan 31 2013 Al Stone <ahs3@redhat.com> - 20130117-5
- Simplify versioning scheme and revert to the original scheme in use by
  iasl, which is use the latest official tarball date (2013017) as the
  version and 1%{?dist} as the release, to be incremented for packaging
  and bug fixes as needed.

* Wed Jan 30 2013 Al Stone <ahs3@redhat.com> - 20130117-4
- Do a little reset: go back to using just the original upstream tarball
  instead of the latest git; the snapshot approach was more complicated
  than needed.
- Upstream tarballs split commands from test suites, so had to add the
  test suite back in as another Source: file.
- Change versioning scheme to include the APCI specification level (5.0),
  the latest official tarball date (2013017) and a revision level  (the
  .1 at the end) for packaging and bug fixes as needed.
- Changed the License field to reflect the source tarball change; the release
  tarball is dual-licensed, Intel ACPI or GPLv2.
- Updated patches to apply cleanly as needed.
- Corrected Obsoletes and Provides version numbers.

* Mon Jan 28 2013 Al Stone <ahs3@redhat.com> - 20130117-3
- Reconcile Fedora and Debian patches to be as alike as possible

* Mon Jan 28 2013 Al Stone <ahs3@redhat.com> - 20130117-2
- Verify ExcludeArch restrictions -- the architectures excluded can have
  no use for these tools.  Hardware support for ACPI is simply not
  implemented for them.
- Corrected versioning to note this source came from a git pull.
- Add License file as upstream has not yet provided one (and has not for
  many years).
- Insert properly versioned Provides and Obsoletes for iasl.
- Corrected files to use man.1* (vs man.1.gz) to allow flexibility in the
  compression being used.

* Wed Jan 23 2013 Al Stone <ahs3@redhat.com> - 20130117-1
- Clone from the current iasl package, with the intent of replacing it
- Update source to latest upstream
- NB: ACPICA documentation would normally be included in a source tarball.
  But, since it is not clearly redistributable, it is not included in the
  source RPM for this package.
- Build all ACPICA tools, not just iasl (and hence the package replacement)
- Add in brief man pages
- Set up acpixtract from this package as an alternative to the same command
  in the pmtools package
- Run a %check step once built

